@@ -1,14 +1,18 @@
+import AppConfiguration from '../config'
 import {
-  GET_VM,
+  CHECK_TOKEN_EXPIRED,
   GET_BY_PAGE,
   GET_OPTION,
   GET_USB_FILTER,
+  GET_VM,
   PERSIST_STATE,
-  SET_ADMINISTATOR,
+  SET_ADMINISTRATOR,
+  SET_USB_FILTER,
   SET_USER_FILTER_PERMISSION,
-  CHECK_TOKEN_EXPIRED,
-  SCHEDULER__1_MIN,
-} from '../constants/index'
+  SHOW_TOKEN_EXPIRED_MSG,
+  START_SCHEDULER_FIXED_DELAY,
+  STOP_SCHEDULER_FIXED_DELAY,
+} from '../constants'
 
 export * from './error'
 export * from './vm'
@@ -19,16 +23,24 @@ export * from './operatingSystems'
 export * from './templates'
 export * from './options'
 export * from './pool'
-export * from './route'
-export * from './storage'
 export * from './storageDomains'
 export * from './dataCenters'
 export * from './pendingTasks'
 export * from './vnicProfiles'
+export * from './activeRequests'
+export * from './console'
+export * from './userMessages'
 
-export function schedulerOneMinute () {
+export function startSchedulerFixedDelay (delayInSeconds = AppConfiguration.schedulerFixedDelayInSeconds) {
   return {
-    type: SCHEDULER__1_MIN,
+    type: START_SCHEDULER_FIXED_DELAY,
+    payload: { delayInSeconds },
+  }
+}
+
+export function stopSchedulerFixedDelay () {
+  return {
+    type: STOP_SCHEDULER_FIXED_DELAY,
     payload: {},
   }
 }
@@ -36,19 +48,19 @@ export function schedulerOneMinute () {
 export function persistState () {
   return {
     type: PERSIST_STATE,
-    payload: {
-    },
+    payload: {},
   }
 }
 
 /**
  * Not creator of an action. Returned object can't be dispatched to the store.
  */
-export function getSingleVm ({ vmId }) {
+export function getSingleVm ({ vmId, shallowFetch = false }) {
   return {
     type: GET_VM,
     payload: {
       vmId,
+      shallowFetch,
     },
   }
 }
@@ -64,7 +76,7 @@ export function setUserFilterPermission (filter) {
 
 export function setAdministrator (administrator) {
   return {
-    type: SET_ADMINISTATOR,
+    type: SET_ADMINISTRATOR,
     payload: {
       administrator,
     },
@@ -80,7 +92,7 @@ export function checkTokenExpired () {
 
 export function showTokenExpiredMessage () {
   return {
-    type: 'SHOW_TOKEN_EXPIRED_MSG',
+    type: SHOW_TOKEN_EXPIRED_MSG,
     payload: {},
   }
 }
@@ -97,7 +109,7 @@ export function getByPage ({ page, shallowFetch = true }) {
 
 export function setUSBFilter ({ usbFilter }) {
   return {
-    type: 'SET_USB_FILTER',
+    type: SET_USB_FILTER,
     payload: {
       usbFilter,
     },
